# Boticord Python Library

Простой Python модуль для работы с Boticord API (не официальный).

### Установка

Установка через pip (рекомендуется)

`pip3 install boticordpy`

### Ссылки

* [Документация](https://boticordpy.readthedocs.io/)
* [Boticord](https://boticord.top/)
